@@ -13,6 +13,7 @@ import subprocess
 import sys
 import time
 import urllib
+import beniutils.print_color as printcolor
 
 import aiohttp
 import chardet
@@ -42,7 +43,27 @@ def initLogger(loggerName=None, loggerLevel=None, logFile=None):
 
     loggerFormatter = logging.Formatter(*LOGGER_FORMAT)
 
-    loggerHandler = logging.StreamHandler()
+    class CustomStreamHandler(logging.StreamHandler):
+        def emit(self, record):
+            try:
+                msg = self.format(record) + self.terminator
+                stream = self.stream
+                # issue 35046: merged two stream.writes into one.
+                func = stream.write
+                if record.levelno == logging.WARNING:
+                    func = printcolor.yellow
+                elif record.levelno == logging.ERROR:
+                    func = printcolor.red
+                elif record.levelno == logging.CRITICAL:
+                    func = printcolor.pink
+                func(msg)
+                self.flush()
+            except RecursionError:  # See issue 36272
+                raise
+            except Exception:
+                self.handleError(record)
+
+    loggerHandler = CustomStreamHandler()
     loggerHandler.setFormatter(loggerFormatter)
     loggerHandler.setLevel(LOGGER_LEVEL)
     logger.addHandler(loggerHandler)
