@@ -3,22 +3,16 @@ import sys
 import time
 
 import beniutils as b
+import beniutils.print_color as printcolor
 
-projectPath = None
 workspacePath = None
 
 
-def init(pPath, wPath):
-    global projectPath
+def init(wPath):
     global workspacePath
-    projectPath = pPath
     workspacePath = wPath
 
 
-def getPathByProject(*parList):
-    return b.getPath(projectPath, *parList)
-
-
 def getPathByWorkspace(*parList):
     return b.getPath(workspacePath, *parList)
 
@@ -46,9 +40,11 @@ def runMain(moduleName=None, **parDict):
         except Exception:
             isError = True
             import traceback
+            printcolor.set_cmd_text_color(printcolor.FOREGROUND_RED)
             traceback.print_exc()
             b.error("执行失败")
         finally:
+            printcolor.resetColor()
             b.remove(lockFile)
         if not isDebug and isError:
             sys.exit(1)
