@@ -8,13 +8,11 @@ parDict = {}
 
 if sys.executable.endswith("python.exe"):
     workspacePath = b.getPath("./../../workspace")
-    projectPath = workspacePath
     import main_config
     moduleName = main_config.moduleName
     parDict = main_config.parDict
 else:
     workspacePath = b.getPath("./workspace")
-    projectPath = workspacePath
 
-bt.init(projectPath, workspacePath)
+bt.init(workspacePath)
 bt.runMain(moduleName, **parDict)
